<div class="warning">

### This page is under construction. Images will be added soon.

</div>

# Manipulators

The Space Robotics Bench provides a variety of robotic arms for simulating manipulation tasks.

## Robotic Arms

#### Canadarm3 (`canadarm3`)

#### Franka Emika (`franka`)

#### Kinova JACO2 — 6 DoF (`kinova_j2n6s`)

#### Kinova JACO2 — 7 DoF (`kinova_j2n7s`)

#### Kinova Gen3 — 7 DoF (`kinova_gen3n7`)

#### SO-ARM100 — 5 DoF (`so_arm100_d5`)

#### SO-ARM100 — 7 DoF (`so_arm100_d7`)

#### Unitree Z1 (`unitree_z1`)

#### UR3 (`ur3`)

#### UR3e (`ur3e`)

#### UR5 (`ur5`)

#### UR5e (`ur5e`)

#### UR10 (`ur10`)

#### UR10e (`ur10e`)

#### UR16e (`ur16e`)

#### UR20 (`ur20`)

#### UR30 (`ur30`)

#### Random UR Manipulator (`random_ur_manipulator`) \[Randomized\]

## End-Effectors

### Active End-Effectors

#### Allegro Hand (`allegro_hand`)

#### Franka Hand (`franka_hand`)

#### Kinova Jaco 2 3-Finger Gripper (`kinova300`)

#### Robotiq Hand-E (`robotiq_hand_e`)

#### Electric Screwdriver M3 (`electric_screwdriver_m3`)

#### Electric Screwdriver M5 (`electric_screwdriver_m5`)

#### Shadow Hand (`shadow_hand`)

#### SO-ARM100 Gripper (`so_arm100_gripper`)

### Passive End-Effectors

#### Rectangular Scoop (`scoop_rectangular`)

#### Spherical Scoop (`scoop_spherical`)

#### Triangular Scoop (`scoop_triangular`)

#### Manual Screwdriver M3 (`manual_screwdriver_m3`)

#### Manual Screwdriver M5 (`manual_screwdriver_m5`)
